@@ -250,7 +250,7 @@ class LoadMaster(HttpClient):
             master_vs_id = int(service.get('MasterVSID', 0))
             if master_vs_id != 0:
                 for vs in services:
-                    if vs.get("Index", 0) == master_vs_id:
+                    if int(vs.get("Index", 0)) == master_vs_id:
                         virt_serv = self.build_virtual_service(service, vs)
             else:
                 virt_serv = self.build_virtual_service(service, response)
@@ -294,7 +294,7 @@ class LoadMaster(HttpClient):
             master_vs_id = int(service_data.get('MasterVSID', 0))
             if master_vs_id != 0:
                 for vs in virtual_services_data:
-                    if vs.get("Index", 0) == master_vs_id:
+                    if int(vs.get("Index", 0)) == master_vs_id:
                         virt_serv = self.build_virtual_service(service_data, vs)
             else:
                 virt_serv = self.build_virtual_service(service_data, response)
@@ -330,11 +330,10 @@ class LoadMaster(HttpClient):
         asfdsfda = service.get('MasterVSID')
         is_sub_vs = True if int(service.get('MasterVSID', 0)) != 0 else False
         if is_sub_vs:
-            print("de subvbs")
             # Add lb properties to the sub vs
             #response = self._get("/showvs", {"vs": service.get('MasterVSID')})
-            parent_vs_data = get_data(response)
-            subvs_lb_props = get_sub_vs_list_from_data(parent_vs_data)[1]
+            #parent_vs_data = get_data(response)
+            subvs_lb_props = get_sub_vs_list_from_data(response)[1]
             virt_serv = VirtualService(self.access_info, service.get('Index'),
                                        is_sub_vs=True)
             virt_serv.subvs_data = subvs_lb_props[service.get('Index')]
